@@ -1,4 +1,4 @@
-#! /usr/bin/env python2
+#! /usr/bin/env python3
 # Copyright (C) 2005, Giovanni Bajo
 # Based on previous work under copyright (c) 2002 McMillan Enterprises, Inc.
 #
@@ -26,7 +26,7 @@ LOAD_LIBRARY_AS_DATAFILE = 2
 import struct
 import types
 try:
-    StringTypes = types.StringTypes
+    StringTypes = (str,)
 except AttributeError:
     StringTypes = [ type("") ]
 
@@ -38,11 +38,11 @@ class Structure:
         for i in range (len (self._names_)):
             indexes[self._names_[i]] = i
     def dump (self):
-        print "I: DUMP of", self
+        print(("I: DUMP of", self))
         for name in self._names_:
             if name[0] != '_':
-                print "I: %20s = %s" % (name, getattr (self, name))
-        print
+                print(("I: %20s = %s" % (name, getattr (self, name))))
+        print()
     def __getattr__ (self, name):
         if name in self._names_:
             index = self._indexes_[name]
@@ -50,7 +50,7 @@ class Structure:
         try:
             return self.__dict__[name]
         except KeyError:
-            raise AttributeError, name
+            raise AttributeError(name)
     def __setattr__ (self, name, value):
         if name in self._names_:
             index = self._indexes_[name]
@@ -58,7 +58,7 @@ class Structure:
         else:
             self.__dict__[name] = value
     def tostring (self):
-        return apply (struct.pack, [self._format_,] + self._fields_)
+        return struct.pack(*[self._format_,] + self._fields_)
     def fromfile (self, file):
         data = file.read (self._sizeInBytes)
         self._fields_ = list (struct.unpack (self._format_, data))
@@ -112,8 +112,8 @@ class IconFile:
 
 def CopyIcons_FromIco (dstpath, srcpath, id=1):
     import win32api #, win32con
-    icons = map(IconFile, srcpath)
-    print "I: Updating icons from", srcpath, "to", dstpath
+    icons = list(map(IconFile, srcpath))
+    print(("I: Updating icons from", srcpath, "to", dstpath))
 
     hdst = win32api.BeginUpdateResource (dstpath, 0)
 
@@ -123,10 +123,10 @@ def CopyIcons_FromIco (dstpath, srcpath, id=1):
         data = f.grp_icon_dir()
         data = data + f.grp_icondir_entries(iconid)
         win32api.UpdateResource (hdst, RT_GROUP_ICON, i, data)
-        print "I: Writing RT_GROUP_ICON %d resource with %d bytes" % (i, len(data))
+        print(("I: Writing RT_GROUP_ICON %d resource with %d bytes" % (i, len(data))))
         for data in f.images:
             win32api.UpdateResource (hdst, RT_ICON, iconid, data)
-            print "I: Writing RT_ICON %d resource with %d bytes" % (iconid, len (data))
+            print(("I: Writing RT_ICON %d resource with %d bytes" % (iconid, len (data))))
             iconid = iconid + 1
 
     win32api.EndUpdateResource (hdst, 0)
@@ -139,13 +139,13 @@ def CopyIcons (dstpath, srcpath):
 
     def splitter(s):
         try:
-            srcpath, index = map(string.strip, string.split(s, ','))
+            srcpath, index = list(map(string.strip, string.split(s, ',')))
             return srcpath, int(index)
         except ValueError:
             return s, None
 
-    srcpath = map(splitter, srcpath)
-    print "I: SRCPATH", srcpath
+    srcpath = list(map(splitter, srcpath))
+    print(("I: SRCPATH", srcpath))
 
     if len(srcpath) > 1:
         # At the moment, we support multiple icons only from .ico files
@@ -153,9 +153,9 @@ def CopyIcons (dstpath, srcpath):
         for s in srcpath:
             e = os.path.splitext(s[0])[1]
             if string.lower(e) != '.ico':
-                raise ValueError, "multiple icons supported only from .ico files"
+                raise ValueError("multiple icons supported only from .ico files")
             if s[1] is not None:
-                raise ValueError, "index not allowed for .ico files"
+                raise ValueError("index not allowed for .ico files")
             srcs.append(s[0])
         return CopyIcons_FromIco(dstpath, srcs)
 
@@ -164,9 +164,9 @@ def CopyIcons (dstpath, srcpath):
     if string.lower (srcext) == '.ico':
         return CopyIcons_FromIco (dstpath, [srcpath])
     if index is not None:
-        print "I: Updating icons from", srcpath, ", %d to" % index, dstpath
+        print(("I: Updating icons from", srcpath, ", %d to" % index, dstpath))
     else:
-        print "I: Updating icons from", srcpath, "to", dstpath
+        print(("I: Updating icons from", srcpath, "to", dstpath))
     import win32api #, win32con
     hdst = win32api.BeginUpdateResource (dstpath, 0)
     hsrc = win32api.LoadLibraryEx (srcpath, 0, LOAD_LIBRARY_AS_DATAFILE)
