@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -29,8 +29,10 @@ import x2go
 # wxPython
 import wx
 
+wx_major = int(wx.__version__.split('.')[0])
+
 # PyHoca-GUI modules
-import basepath
+from . import basepath
 
 class PyHocaGUI_AboutFrame(wx.Frame):
     """\
@@ -76,9 +78,9 @@ class PyHocaGUI_AboutFrame(wx.Frame):
             about_what = self._PyHocaGUI.appname
 
         if x2go.X2GOCLIENT_OS == 'Windows':
-            wx.Frame.__init__(self, None, -1, _(u'About %s ...') % about_what, size=(403,340))
+            wx.Frame.__init__(self, None, -1, _('About %s ...') % about_what, size=(403,340))
         else:
-            wx.Frame.__init__(self, None, -1, _(u'About %s ...') % about_what, size=(400,298))
+            wx.Frame.__init__(self, None, -1, _('About %s ...') % about_what, size=(400,298))
         self.Bind(wx.EVT_CLOSE, self.OnHide)
 
         panel = wx.Panel(self, -1, pos=(0,0), size=(0,0), )
@@ -114,7 +116,10 @@ class PyHocaGUI_AboutFrame(wx.Frame):
             icon_file = '%s/%s/%s/%s' % (basepath.icons_basepath, icon_folder, icon_size, icon_name)
 
         img = wx.Image(icon_file)
-        icon = wx.IconFromBitmap(img.ConvertToBitmap())
+        if wx_major < 4:
+            icon = wx.IconFromBitmap(img.ConvertToBitmap())
+        else:
+            icon = wx.Icon(img.ConvertToBitmap())
         self.icon = self.SetIcon(icon)
 
         self.CenterOnScreen()
