@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@ import os
 from x2go import X2GOCLIENT_OS as _X2GOCLIENT_OS
 
 def reload_base_paths():
-    if os.environ.has_key('PYHOCAGUI_DEVELOPMENT') and os.environ['PYHOCAGUI_DEVELOPMENT'] == '1':
+    if 'PYHOCAGUI_DEVELOPMENT' in os.environ and os.environ['PYHOCAGUI_DEVELOPMENT'] == '1':
         _base_location = os.path.abspath(os.path.curdir)
         _icons_location = os.path.join(_base_location, 'icons')
         _images_location = os.path.join(_base_location, 'img')
