@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -27,9 +27,9 @@ import x2go
 import wx
 import os
 
-import messages
+from . import messages
 
-if os.environ.has_key('DESKTOP_SESSION'):
+if 'DESKTOP_SESSION' in os.environ:
     WINDOW_MANAGER = os.environ['DESKTOP_SESSION']
 else:
     WINDOW_MANAGER = 'generic'
@@ -52,16 +52,16 @@ class PyHocaGUI_BrokerDialogBoxPassword(wx.Dialog):
         self._pyhoca_logger = self._PyHocaGUI._pyhoca_logger
         self._pyhoca_logger('password dialog box started', loglevel=x2go.loglevel_INFO, )
 
-        wx.Dialog.__init__(self, None, id=-1, title=self._PyHocaGUI.broker_name + ' ' + _(u'Logon'), style=wx.DEFAULT_FRAME_STYLE, )
+        wx.Dialog.__init__(self, None, id=-1, title=self._PyHocaGUI.broker_name + ' ' + _('Logon'), style=wx.DEFAULT_FRAME_STYLE, )
         self._PyHocaGUI._sub_windows.append(self)
 
-        self.brokerLbl = wx.StaticText(self, wx.ID_ANY, _(u'Broker URL')+':', size=(-1, -1))
+        self.brokerLbl = wx.StaticText(self, wx.ID_ANY, _('Broker URL')+':', size=(-1, -1))
         self.brokerTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(240, -1))
 
-        self.userLbl = wx.StaticText(self, wx.ID_ANY, _(u'Username')+':', size=(-1, -1))
+        self.userLbl = wx.StaticText(self, wx.ID_ANY, _('Username')+':', size=(-1, -1))
         self.userTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER, size=(240, -1))
 
-        self.passwordLbl = wx.StaticText(self, wx.ID_ANY, _(u'Password')+':', size=(-1, -1))
+        self.passwordLbl = wx.StaticText(self, wx.ID_ANY, _('Password')+':', size=(-1, -1))
         self.passwordTxt = wx.TextCtrl(self, wx.ID_ANY, '', style=wx.TE_PROCESS_ENTER|wx.TE_PASSWORD, size=(240, -1))
         self.passwordTxt.SetFocus()
 
@@ -82,9 +82,9 @@ class PyHocaGUI_BrokerDialogBoxPassword(wx.Dialog):
             else:
                 self.brokerTxt.SetValue(self._PyHocaGUI.session_profiles.get_broker_url())
 
-        self.loginBtn = wx.Button(self, wx.ID_OK, _(u'Authenticate'), )
+        self.loginBtn = wx.Button(self, wx.ID_OK, _('Authenticate'), )
         self.loginBtn.SetDefault()
-        self.cancelBtn = wx.Button(self, wx.ID_CANCEL, _(u'Cancel'), )
+        self.cancelBtn = wx.Button(self, wx.ID_CANCEL, _('Cancel'), )
         _tab_order = [self.userTxt, self.passwordTxt, self.loginBtn, self.cancelBtn, ]
 
         self.Bind(wx.EVT_BUTTON, self.OnLogin, self.loginBtn)
@@ -116,7 +116,7 @@ class PyHocaGUI_BrokerDialogBoxPassword(wx.Dialog):
         self.SetSizerAndFit(mainSizer)
         self.Layout()
 
-        for i in xrange(len(_tab_order) - 1):
+        for i in range(len(_tab_order) - 1):
             _tab_order[i+1].MoveAfterInTabOrder(_tab_order[i])
 
         maxX, maxY = wx.GetDisplaySize()
@@ -163,13 +163,13 @@ class PyHocaGUI_BrokerDialogBoxPassword(wx.Dialog):
         self._PyHocaGUI.session_profiles.set_broker_url(broker_url)
         try:
             if self._PyHocaGUI.session_profiles.broker_simpleauth(username, password):
-                self._PyHocaGUI.notifier.send(_(u"%s - success") % self._PyHocaGUI.broker_name, _(u"Authentication to session broker has been\nsuccessful."), icon='auth_success', timeout=10000)
+                self._PyHocaGUI.notifier.send(_("%s - success") % self._PyHocaGUI.broker_name, _("Authentication to session broker has been\nsuccessful."), icon='auth_success', timeout=10000)
             else:
-                self._PyHocaGUI.notifier.send(_(u"%s - failure") % self._PyHocaGUI.broker_name, _(u"Authentication to session broker failed."), icon='auth_failed', timeout=10000)
+                self._PyHocaGUI.notifier.send(_("%s - failure") % self._PyHocaGUI.broker_name, _("Authentication to session broker failed."), icon='auth_failed', timeout=10000)
             self.Close()
             self.Destroy()
         except x2go.x2go_exceptions.X2GoBrokerConnectionException:
-            m = messages.PyHoca_MessageWindow_YesNo(self._PyHocaGUI, title=_(u'%s: Connection refused error') % self._PyHocaGUI.appname, msg=_(u'Connection to %s failed. Retry?') % self._PyHocaGUI.broker_name, icon='connect_error')
+            m = messages.PyHoca_MessageWindow_YesNo(self._PyHocaGUI, title=_('%s: Connection refused error') % self._PyHocaGUI.appname, msg=_('Connection to %s failed. Retry?') % self._PyHocaGUI.broker_name, icon='connect_error')
             m.ShowModal()
             if m.No():
                 self.Close()
