@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -31,6 +31,8 @@ import copy
 
 import wx
 
+wx_major = int(wx.__version__.split('.')[0])
+
 # we need to register a wx.App() instance before we load any
 # of the X2Go modules. When importing x2go.*, gevent.monkey_patch_all()
 # is called which seems to break wxPython 3.0...
@@ -42,11 +44,11 @@ from x2go import BACKENDS
 from x2go import X2GoLogger
 
 from pyhoca.wxgui import __VERSION__
-from frontend import PyHocaGUI
-from messages import PyHoca_MessageWindow_Ok
+from .frontend import PyHocaGUI
+from .messages import PyHoca_MessageWindow_Ok
 
-import defaults
-import basepath
+from . import defaults
+from . import basepath
 
 
 class PyHocaGUI_Launcher(object):
@@ -94,7 +96,7 @@ VERSION: %s
             os.environ.update({'NXPROXY_BINARY': nxproxy_binary, })
 
     def modify_default_option(self, option, value):
-        if self.default_options.has_key(option):
+        if option in self.default_options:
             if type(self.default_options[option]) == type(value):
                 self.default_options[option] = value
 
@@ -102,7 +104,7 @@ VERSION: %s
         if sys.argv[0].startswith('./') or sys.argv[0].startswith('python'):
             sys.path.insert(0, os.getcwd())
             os.environ['PYHOCAGUI_DEVELOPMENT'] = '1'
-            print '### {progname} running in development mode ###'.format(progname=self.PROG_NAME)
+            print('### {progname} running in development mode ###'.format(progname=self.PROG_NAME))
             basepath.reload_base_paths()
 
     def check_running(self):
@@ -112,7 +114,12 @@ VERSION: %s
 
             p = subprocess.Popen(['ps', '-U', CURRENT_LOCAL_USER, '-u', CURRENT_LOCAL_USER], stdout=subprocess.PIPE)
             psA_out = p.communicate()
-            if psA_out[0].count(_executable) <= 1:
+            if sys.version_info[0] < 3:
+                num_of_processes = psA_out[0].count(_executable)
+            else:
+                num_of_processes = psA_out[0].count(_executable.encode())
+
+            if num_of_processes <= 1:
 
                 if os.path.isdir(os.path.expanduser("~/.x2go/{progname}/".format(progname=_executable))):
                     shutil.rmtree(os.path.expanduser("~/.x2go/{progname}/".format(progname=_executable)))
@@ -135,8 +142,8 @@ VERSION: %s
 
                 if display.split('.')[0] == my_display.split('.')[0]:
                     other_pid = pidfile.split('.')[1]
-                    print
-                    print('One instance of {progname} (PID: {other_pid}) is already running for this $DISPLAY {display}'.format(progname=_executable, other_pid=other_pid, display=my_display))
+                    print()
+                    print(('One instance of {progname} (PID: {other_pid}) is already running for this $DISPLAY {display}'.format(progname=_executable, other_pid=other_pid, display=my_display)))
 
                     return True
 
@@ -149,7 +156,7 @@ VERSION: %s
             for process in w.Win32_Process():
                 if process.Name == _executable:
                     _p[process.ProcessId] = process.SessionId
-            return len([ _p_id for _p_id in _p.keys() if _p[self.PROG_PID] ==  _p[_p_id] ]) > 1
+            return len([ _p_id for _p_id in list(_p.keys()) if _p[self.PROG_PID] ==  _p[_p_id] ]) > 1
 
 
     def version(self):
@@ -203,7 +210,7 @@ VERSION: %s
             _config_backends = ('FILE')
 
         _default_options = copy.deepcopy(self.default_options)
-        for key in _default_options.keys():
+        for key in list(_default_options.keys()):
             if not _default_options[key]:
                 _default_options[key] = None
 
@@ -259,11 +266,11 @@ VERSION: %s
             )
 
         backend_options = [
-            {'args':['--backend-controlsession'], 'default': _default_options['backend_controlsession'], 'metavar': '<CONTROLSESSION_BACKEND>', 'choices': BACKENDS['X2GoControlSession'].keys(), 'help': 'force usage of a certain CONTROLSESSION_BACKEND (do not use this unless you know exactly what you are doing)', },
-            {'args':['--backend-terminalsession'], 'default': _default_options['backend_terminalsession'], 'metavar': '<TERMINALSESSION_BACKEND>', 'choices': BACKENDS['X2GoTerminalSession'].keys(), 'help': 'force usage of a certain TERMINALSESSION_BACKEND (do not use this unless you know exactly what you are doing)', },
-            {'args':['--backend-serversessioninfo'], 'default': _default_options['backend_serversessioninfo'], 'metavar': '<SERVERSESSIONINFO_BACKEND>', 'choices': BACKENDS['X2GoServerSessionInfo'].keys(), 'help': 'force usage of a certain SERVERSESSIONINFO_BACKEND (do not use this unless you know exactly what you are doing)', },
-            {'args':['--backend-serversessionlist'], 'default': _default_options['backend_serversessionlist'], 'metavar': '<SERVERSESSIONLIST_BACKEND>', 'choices': BACKENDS['X2GoServerSessionList'].keys(), 'help': 'force usage of a certain SERVERSESSIONLIST_BACKEND (do not use this unless you know exactly what you are doing)', },
-            {'args':['--backend-proxy'], 'default': _default_options['backend_proxy'], 'metavar': '<PROXY_BACKEND>', 'choices': BACKENDS['X2GoProxy'].keys(), 'help': 'force usage of a certain PROXY_BACKEND (do not use this unless you know exactly what you are doing)', },
+            {'args':['--backend-controlsession'], 'default': _default_options['backend_controlsession'], 'metavar': '<CONTROLSESSION_BACKEND>', 'choices': list(BACKENDS['X2GoControlSession'].keys()), 'help': 'force usage of a certain CONTROLSESSION_BACKEND (do not use this unless you know exactly what you are doing)', },
+            {'args':['--backend-terminalsession'], 'default': _default_options['backend_terminalsession'], 'metavar': '<TERMINALSESSION_BACKEND>', 'choices': list(BACKENDS['X2GoTerminalSession'].keys()), 'help': 'force usage of a certain TERMINALSESSION_BACKEND (do not use this unless you know exactly what you are doing)', },
+            {'args':['--backend-serversessioninfo'], 'default': _default_options['backend_serversessioninfo'], 'metavar': '<SERVERSESSIONINFO_BACKEND>', 'choices': list(BACKENDS['X2GoServerSessionInfo'].keys()), 'help': 'force usage of a certain SERVERSESSIONINFO_BACKEND (do not use this unless you know exactly what you are doing)', },
+            {'args':['--backend-serversessionlist'], 'default': _default_options['backend_serversessionlist'], 'metavar': '<SERVERSESSIONLIST_BACKEND>', 'choices': list(BACKENDS['X2GoServerSessionList'].keys()), 'help': 'force usage of a certain SERVERSESSIONLIST_BACKEND (do not use this unless you know exactly what you are doing)', },
+            {'args':['--backend-proxy'], 'default': _default_options['backend_proxy'], 'metavar': '<PROXY_BACKEND>', 'choices': list(BACKENDS['X2GoProxy'].keys()), 'help': 'force usage of a certain PROXY_BACKEND (do not use this unless you know exactly what you are doing)', },
             {'args':['--backend-sessionprofiles'], 'default': _default_options['backend_sessionprofiles'], 'metavar': '<SESSIONPROFILES_BACKEND>', 'choices': _config_backends, 'help': 'use given backend for accessing session profiles, available backends on your system: %s (default: %s)' % (', '.join(_config_backends), _profiles_backend_default), },
             {'args':['--backend-clientsettings'], 'default': _default_options['backend_clientsettings'], 'metavar': '<CLIENTSETTINGS_BACKEND>', 'choices': _config_backends, 'help': 'use given backend for accessing the client settings configuration, available backends on your system: %s (default: %s)' % (', '.join(_config_backends), _settings_backend_default), },
             {'args':['--backend-clientprinting'], 'default': _default_options['backend_clientprinting'], 'metavar': '<CLIENTPRINTING_BACKEND>', 'choices': _config_backends, 'help': 'use given backend for accessing the client printing configuration, available backends on your system: %s (default: %s)' % (', '.join(_config_backends), _printing_backend_default), },
@@ -381,14 +388,14 @@ VERSION: %s
                 lang = gettext.translation('PyHoca-GUI', localedir=basepath.locale_basepath, languages=[args.lang], )
             else:
                 lang = gettext.translation('PyHoca-GUI', localedir=basepath.locale_basepath, languages=['en'], )
-            lang.install(unicode=True)
+            lang.install(str=True)
         else:
-            gettext.install('PyHoca-GUI', localedir=basepath.locale_basepath, unicode=True)
+            gettext.install('PyHoca-GUI', localedir=basepath.locale_basepath)
 
         if self.check_running():
             sys.stderr.write("\n###############################\n### %s: already running for user %s\n###############################\n" % (self.PROG_NAME, CURRENT_LOCAL_USER))
             _dummy_app.appname = self.PROG_NAME
-            m = PyHoca_MessageWindow_Ok(_dummy_app, shortmsg='ALREADY_RUNNING', title=u'%s (%s)...' % (self.PROG_NAME, self.VERSION), icon='{progname}_trayicon'.format(progname=self.PROG_NAME))
+            m = PyHoca_MessageWindow_Ok(_dummy_app, shortmsg='ALREADY_RUNNING', title='%s (%s)...' % (self.PROG_NAME, self.VERSION), icon='{progname}_trayicon'.format(progname=self.PROG_NAME))
             m.ShowModal()
             self.version()
 
@@ -398,11 +405,11 @@ VERSION: %s
             thisPyHocaGUI.MainLoop()
         except KeyboardInterrupt:
             if thisPyHocaGUI is not None:
-                thisPyHocaGUI.WakeUpIdle()
+                if wx_major < 4: thisPyHocaGUI.WakeUpIdle()
                 thisPyHocaGUI.ExitMainLoop()
         except SystemExit:
             if thisPyHocaGUI is not None:
-                thisPyHocaGUI.WakeUpIdle()
+                if wx_major < 4: thisPyHocaGUI.WakeUpIdle()
                 thisPyHocaGUI.ExitMainLoop()
 
         self.remove_pidfile()
