@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -26,7 +26,7 @@ import wx
 import os
 
 # PyHoca-GUI modules
-import basepath
+from . import basepath
 
 # X2Go modules
 from x2go.defaults import CURRENT_LOCAL_USER as _CURRENT_LOCAL_USER
@@ -68,14 +68,14 @@ class PyHoca_MessageWindow(wx.Dialog):
         except: pass
 
         self._pyhoca_messages = {
-            'REALLY_DELETE_PROFILE': _(u'Are you really sure you want to\ndelete the session profile ,,%s\'\'?') % profile_name,
-            'ALREADY_RUNNING': _(u'{appname} is already running for user ,,{username}\'\'!\n\nOnly one instance of {appname} can be started per\nuser. The {appname} icon can be found in your desktop\'s\nnotification area/systray.').format(appname=self._PyHocaGUI.appname, username=_CURRENT_LOCAL_USER)
+            'REALLY_DELETE_PROFILE': _('Are you really sure you want to\ndelete the session profile ,,%s\'\'?') % profile_name,
+            'ALREADY_RUNNING': _('{appname} is already running for user ,,{username}\'\'!\n\nOnly one instance of {appname} can be started per\nuser. The {appname} icon can be found in your desktop\'s\nnotification area/systray.').format(appname=self._PyHocaGUI.appname, username=_CURRENT_LOCAL_USER)
         }
 
 
         if shortmsg is None:
             show_message = msg
-        elif shortmsg in self._pyhoca_messages.keys():
+        elif shortmsg in list(self._pyhoca_messages.keys()):
             show_message = self._pyhoca_messages[shortmsg]
         else:
             show_message = 'No message has been given...'
@@ -107,8 +107,8 @@ class PyHoca_MessageWindow(wx.Dialog):
         mainSizer = wx.BoxSizer(wx.VERTICAL)
 
         if buttontype in ('yesno', 'noyes'):
-            self.yesBtn = wx.Button(self, wx.ID_ANY, _(u'Yes'),)
-            self.noBtn = wx.Button(self, wx.ID_ANY, _(u'No'))
+            self.yesBtn = wx.Button(self, wx.ID_ANY, _('Yes'),)
+            self.noBtn = wx.Button(self, wx.ID_ANY, _('No'))
 
             self.Bind(wx.EVT_BUTTON, self.OnTrue, self.yesBtn)
             self.Bind(wx.EVT_BUTTON, self.OnFalse, self.noBtn)
@@ -125,13 +125,13 @@ class PyHoca_MessageWindow(wx.Dialog):
 
         if buttontype in ('ok', 'okcancel', 'cancelok'):
 
-            self.okBtn = wx.Button(self, wx.ID_ANY, _(u'Ok'),)
+            self.okBtn = wx.Button(self, wx.ID_ANY, _('Ok'),)
             self.Bind(wx.EVT_BUTTON, self.OnTrue, self.okBtn)
             btnSizer.Add(self.okBtn, flag=wx.ALL, border=5)
 
         if buttontype in ('okcancel', 'cancelok'):
 
-            self.cancelBtn = wx.Button(self, wx.ID_ANY, _(u'Cancel'))
+            self.cancelBtn = wx.Button(self, wx.ID_ANY, _('Cancel'))
             self.Bind(wx.EVT_BUTTON, self.OnFalse, self.cancelBtn)
             btnSizer.Add(self.cancelBtn, flag=wx.ALL, border=5)
 
