@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -19,24 +19,139 @@
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
+import sys
 import wx
 from x2go import X2GOCLIENT_OS
 from x2go import log
 if X2GOCLIENT_OS in ('Linux', 'Mac'):
     try:
         # try the GTK3 way for notification support first...
+        from gi import require_version
+        require_version('Notify', '0.7')
         from gi.repository import Notify as _Notify
     except ImportError:
         # GTK3 notifications are unavailable,
         # hopefully pynotify / GTK2-based notifications are available then...
         import pynotify as _Notify
-import exceptions
-import basepath
+from . import basepath
 
 import x2go.utils as utils
 
-class NotSupportedException(exceptions.StandardError): pass
-class PyHocaNotificationException(exceptions.StandardError): pass
+class NotSupportedException(BaseException): pass
+class PyHocaNotificationException(BaseException): pass
+
+def notification_service_available():
+    return _Notify.get_server_info()[0]
+
+class stdout_NotifierPopup(object):
+    """\
+    L{PyHocaGUI} stdout notifications, used when no desktop notification service is available.
+
+    """
+    title = {}
+    text = {}
+    icon = {}
+    timeout = {}
+
+    def __init__(self, _PyHocaGUI):
+        """\
+        Notifier popup (constructor).
+
+        @param _PyHocaGUI: main application instance
+        @type _PyHocaGUI: C{obj}
+
+        """
+        self._PyHocaGUI = _PyHocaGUI
+        self._pyhoca_logger = self._PyHocaGUI._pyhoca_logger
+
+    def prepare(self, context, title=None, text=None, icon=None, timeout=None):
+        """\
+        Prepare a notification that gets sent to stdout later (by the L{send()} method).
+
+        Use C{context} as a unique identifier. When sending the notification later, C{context}
+        will unequivocally map to the notification content that shall get sent.
+
+        @param context: a unique identifier for this notification preparation
+        @type context: C{str}
+        @param title: notification title
+        @type title: C{str}
+        @param text: notification text
+        @type text: C{str}
+        @param icon: icon name for an icon that appears with the notification
+        @type icon: C{str}
+        @param timeout: let notification disappear after C{<timeout>} milliseconds
+        @type timeout: C{int}
+
+        """
+        if title is not None:
+            self.title[context] = title
+        if text is not None:
+            self.text[context] = text
+        if icon is not None:
+            self.icon[context] = icon
+        if timeout is not None:
+            self.timeout[context] = timeout
+
+    def send(self, title=None, text=None, context=None, icon=None, timeout=8000):
+        """\
+        Send notifications directly to stdout (or use a prepared notification).
+
+        @param title: notification title
+        @type title: C{str}
+        @param text: notification text
+        @type text: C{str}
+        @param context: an identifier that refers to a prepared notification
+        @type context: C{str}
+        @param icon: icon name for an icon that appears with the notification
+        @type icon: C{str}
+        @param timeout: let notification disappear after C{<timeout>} milliseconds
+        @type timeout: C{int}
+
+        @raise PyHocaNotificationException: if notification failed
+
+        """
+        if context is not None:
+            try:
+                title = self.title[context]
+                del self.title[context]
+            except KeyError:
+                pass
+            try:
+                text = self.text[context]
+                del self.text[context]
+            except KeyError:
+                pass
+            try:
+                icon = self.icon[context]
+                del self.icon[context]
+            except KeyError:
+                pass
+            try:
+                timeout = self.timeout[context]
+                del self.timeout[context]
+            except KeyError:
+                pass
+
+        if title and text:
+            if sys.version_info[0] >= 3:
+                self._pyhoca_logger('[%s] %s' % (title, text), loglevel=log.loglevel_NOTICE)
+            else:
+                self._pyhoca_logger('[%s] %s' % (title.encode(utils.get_encoding()), text.encode(utils.get_encoding())), loglevel=log.loglevel_NOTICE)
+
+    def Close(self):
+        """\
+        Provide a C{Close()} method which does nothing.
+
+        """
+        pass
+
+    def Destroy(self):
+        """\
+        Provide a C{Destroy()} method which does nothing.
+
+        """
+        pass
+
 
 class libnotify_NotifierPopup(object):
     """\
@@ -134,7 +249,9 @@ class libnotify_NotifierPopup(object):
         if icon:
             icon = 'file://%s/PyHoca/32x32/%s.png' % (_icons_location, icon)
 
-        if title and text:
+        if sys.version_info[0] >= 3:
+            self._pyhoca_logger('[%s] %s' % (title, text), loglevel=log.loglevel_NOTICE)
+        else:
             self._pyhoca_logger('[%s] %s' % (title.encode(utils.get_encoding()), text.encode(utils.get_encoding())), loglevel=log.loglevel_NOTICE)
 
         try:
@@ -276,7 +393,7 @@ class showballoon_NotifierPopup(object):
             'session_terminate': wx.ICON_INFORMATION,
             'session_warning': wx.ICON_WARNING,
         }
-        if icon in _icon_map_wx.keys():
+        if icon in list(_icon_map_wx.keys()):
            icon = _icon_map_wx[icon]
         else:
            icon = wx.ICON_INFORMATION
@@ -430,7 +547,7 @@ class notificationmessage_NotifierPopup(object):
             'session_terminate': wx.ICON_INFORMATION,
             'session_warning': wx.ICON_WARNING,
         }
-        if icon in _icon_map_wx.keys():
+        if icon in list(_icon_map_wx.keys()):
            icon = _icon_map_wx[icon]
         else:
            icon = wx.ICON_INFORMATION
