@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -35,9 +35,7 @@ if _X2GOCLIENT_OS != "Windows":
 else:
     import win32print
 
-import basepath
-
-_icons_location = basepath.icons_basepath
+from . import basepath
 
 class PyHocaGUI_PrintingPreferences(wx.Dialog):
     """\
@@ -62,24 +60,26 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
         self._pyhoca_logger = self._PyHocaGUI._pyhoca_logger
         self.mode = mode
 
+        _icons_location = basepath.icons_basepath
+
         self._pyhoca_logger('opening client printing configuration dialog, mode: ,,%s\'\'' % self.mode, loglevel=log.loglevel_INFO)
 
         if self.mode == 'edit':
-            _title = _(u'%s - Printing Preferences') % self._PyHocaGUI.appname
+            _title = _('%s - Printing Preferences') % self._PyHocaGUI.appname
         else:
-            _title = _(u'%s - Incoming Print Job from  %s (%s)') % (self._PyHocaGUI.appname, profile_name, session_name)
+            _title = _('%s - Incoming Print Job from  %s (%s)') % (self._PyHocaGUI.appname, profile_name, session_name)
         wx.Dialog.__init__(self, None, -1, title=_title, style=wx.DEFAULT_DIALOG_STYLE, )
         self._PyHocaGUI._sub_windows.append(self)
 
         self._availablePrintActions = {
-            'DIALOG': _(u'Open this dialog window'),
-            'PDFVIEW': _(u'Open with PDF viewer'),
-            'PDFSAVE': _(u'Save to a local folder'),
-            'PRINT': _(u'Print to a local printer'),
-            'PRINTCMD': _(u'Run custom print command'),
+            'DIALOG': _('Open this dialog window'),
+            'PDFVIEW': _('Open with PDF viewer'),
+            'PDFSAVE': _('Save to a local folder'),
+            'PRINT': _('Print to a local printer'),
+            'PRINTCMD': _('Run custom print command'),
             }
         if self.mode != 'edit':
-            self._availablePrintActions['DIALOG'] = _(u'<Select a print action here>')
+            self._availablePrintActions['DIALOG'] = _('<Select a print action here>')
 
         self._availablePrinters = {}
         if _X2GOCLIENT_OS != "Windows":
@@ -88,7 +88,7 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
                 cups.setUser(_CURRENT_LOCAL_USER)
                 cups_connection = cups.Connection()
                 cups_printers = cups_connection.getPrinters()
-                for p in cups_printers.keys():
+                for p in list(cups_printers.keys()):
                     self._availablePrinters.update({ p: '%s (%s)' % (p, cups_printers[p]['printer-info']), })
                 self._defaultPrinter = cups_connection.getDefault()
             except RuntimeError:
@@ -113,40 +113,40 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
         ### widgets for CLIENT PRINTING
         ###
         if self.mode != 'edit':
-            self.PrintActionLabel = wx.StaticText(self, -1, _(u"Print action")+':')
+            self.PrintActionLabel = wx.StaticText(self, -1, _("Print action")+':')
         else:
-            self.PrintActionLabel = wx.StaticText(self, -1, _(u"Default action for incoming print jobs")+':')
-        self.PrintAction = wx.ComboBox(self, -1, choices=self._availablePrintActions.values(), style=wx.CB_DROPDOWN|wx.CB_READONLY)
+            self.PrintActionLabel = wx.StaticText(self, -1, _("Default action for incoming print jobs")+':')
+        self.PrintAction = wx.ComboBox(self, -1, choices=list(self._availablePrintActions.values()), style=wx.CB_DROPDOWN|wx.CB_READONLY)
 
         # widgets for print action PDFVIEW
-        self.PdfViewCmdLabel = wx.StaticText(self, -1, _(u'PDF viewer command') + ':', )
+        self.PdfViewCmdLabel = wx.StaticText(self, -1, _('PDF viewer command') + ':', )
         self.PdfViewCmd = wx.TextCtrl(self, -1, '', )
         self.PdfViewCmdBrowseButton = wx.BitmapButton(self, -1,
                                                       wx.Bitmap('%s/PyHoca/16x16/system-search.png' % _icons_location, wx.BITMAP_TYPE_ANY)
                                                      )
 
         # widgets for print action PDFSAVE
-        self.PdfSaveToFolderLabel = wx.StaticText(self, -1, _(u'Save PDFs to folder') + ':', )
+        self.PdfSaveToFolderLabel = wx.StaticText(self, -1, _('Save PDFs to folder') + ':', )
         self.PdfSaveToFolder = wx.TextCtrl(self, -1, '', )
         self.PdfSaveToFolderBrowseButton = wx.BitmapButton(self, -1,
                                                            wx.Bitmap('%s/PyHoca/16x16/system-search.png' % _icons_location, wx.BITMAP_TYPE_ANY)
                                                           )
 
         # widgets for print action PRINT
-        self.PrintPrinterLabel = wx.StaticText(self, -1, _(u'Use this printer') + ':', )
-        self.PrintPrinter = wx.ComboBox(self, -1, choices=self._availablePrinters.values(), style=wx.CB_DROPDOWN|wx.CB_READONLY)
+        self.PrintPrinterLabel = wx.StaticText(self, -1, _('Use this printer') + ':', )
+        self.PrintPrinter = wx.ComboBox(self, -1, choices=list(self._availablePrinters.values()), style=wx.CB_DROPDOWN|wx.CB_READONLY)
 
         # widgets for print action PRINTCMD
-        self.PrintCmdLabel = wx.StaticText(self, -1, _(u'Custom print command') + ':', )
+        self.PrintCmdLabel = wx.StaticText(self, -1, _('Custom print command') + ':', )
         self.PrintCmd = wx.TextCtrl(self, -1, '', )
 
         if self.mode == 'edit':
-            self.OKButton = wx.Button(self, wx.ID_OK, _(u"Ok"))
-            self.ApplyButton = wx.Button(self, -1, _(u"Apply"))
+            self.OKButton = wx.Button(self, wx.ID_OK, _("Ok"))
+            self.ApplyButton = wx.Button(self, -1, _("Apply"))
         else:
-            self.OKButton = wx.Button(self, wx.ID_OK, _(u"Print"))
+            self.OKButton = wx.Button(self, wx.ID_OK, _("Print"))
         self.OKButton.SetDefault()
-        self.CancelButton = wx.Button(self, wx.ID_CANCEL, _(u"Cancel"))
+        self.CancelButton = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
 
         self.__set_properties()
         self.__update_fields()
@@ -246,21 +246,21 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
                     if self._defaultPrinter != None:
                         _printer_name = self._availablePrinters[self._defaultPrinter]
                     else:
-                        _printer_name = self._availablePrinters[self._availablePrinters.keys()[0]]
+                        _printer_name = self._availablePrinters[list(self._availablePrinters.keys())[0]]
             else:
-                _printer_name = _(u'- no printers installed -')
+                _printer_name = _('- no printers installed -')
                 self.PrintPrinter.Clear()
                 self.PrintPrinter.Append(_(_printer_name))
                 self.PrintPrinter.Enable(False)
         else:
-            _printer_name = _(u'- print system is not available -')
+            _printer_name = _('- print system is not available -')
             self.PrintPrinter.Clear()
             self.PrintPrinter.Append(_(_printer_name))
             self.PrintPrinter.Enable(False)
         self.PrintPrinter.SetValue(_printer_name)
         self.PrintCmd.SetValue(self.client_printing.get_property('print_cmd'))
 
-        if self._availablePrintActions.has_key(print_action_name):
+        if print_action_name in self._availablePrintActions:
             self.PrintAction.SetValue(self._availablePrintActions[print_action_name])
         else:
             self.PrintAction.SetValue(print_action_name)
@@ -275,13 +275,13 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
 
     @property
     def _print_action(self):
-        return [ p for p in self._availablePrintActions.keys() if self._availablePrintActions[p] == self.PrintAction.GetValue() ][0]
+        return [ p for p in list(self._availablePrintActions.keys()) if self._availablePrintActions[p] == self.PrintAction.GetValue() ][0]
 
     @property
     def _print_action_properties(self):
 
         # handle missing print system
-        _printer = [ p for p in self._availablePrinters.keys() if self._availablePrinters[p] == self.PrintPrinter.GetValue() and self._defaultPrinter != '#PRINTSYSTEM_UNAVAILABLE#' ]
+        _printer = [ p for p in list(self._availablePrinters.keys()) if self._availablePrinters[p] == self.PrintPrinter.GetValue() and self._defaultPrinter != '#PRINTSYSTEM_UNAVAILABLE#' ]
         try:
             _printer = _printer[0]
         except IndexError:
@@ -407,7 +407,7 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
         """
         wildcard = "All files (*.*)|*"
         dlg = wx.FileDialog(
-            self, message=_(u"Choose PDF viewer application"), defaultDir=_LOCAL_HOME,
+            self, message=_("Choose PDF viewer application"), defaultDir=_LOCAL_HOME,
             defaultFile="", wildcard=wildcard, style=wx.FD_OPEN | wx.FD_CHANGE_DIR )
         # Show the dialog and retrieve the user response. If it is the OK response,
         # process the data.
@@ -430,7 +430,7 @@ class PyHocaGUI_PrintingPreferences(wx.Dialog):
                 _start_dir = '~/%s' % _start_dir
             _start_dir = os.path.expanduser(_start_dir)
         dlg = wx.DirDialog(
-            self, message=_(u"Choose PDF saving location"), style=1, defaultPath=_start_dir, )
+            self, message=_("Choose PDF saving location"), style=1, defaultPath=_start_dir, )
         # Show the dialog and retrieve the user response. If it is the OK response,
         # process the data.
         if dlg.ShowModal() == wx.ID_OK:
