@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@ import os
 # PyHoca-GUI modules
 # ... NONE ...
 
-if os.environ.has_key('DESKTOP_SESSION'):
+if 'DESKTOP_SESSION' in os.environ:
     WINDOW_MANAGER = os.environ['DESKTOP_SESSION']
 else:
     WINDOW_MANAGER = 'generic'
@@ -59,15 +59,15 @@ class PyHocaGUI_DialogBoxServerInfo(wx.Dialog):
         wx.Dialog.__init__(self, None, id=-1, title=profile_name, style=wx.DEFAULT_FRAME_STYLE, )
         self._PyHocaGUI._sub_windows.append(self)
 
-        self.SetTitle(_(u'Server Information - %s') % profile_name)
+        self.SetTitle(_('Server Information - %s') % profile_name)
 
-        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _(u'Session Profile: %s\n\nList of X2Go Server components, add-ons and their versions...') % self.current_profile_name, size=(-1, -1))
+        self.titleLbl = wx.StaticText(self, wx.ID_ANY, _('Session Profile: %s\n\nList of X2Go Server components, add-ons and their versions...') % self.current_profile_name, size=(-1, -1))
 
         self.infoArea = wx.TextCtrl(self, id=-1, value="", size=(520,300), style=wx.TE_READONLY|wx.TE_MULTILINE|wx.SUNKEN_BORDER)
 
         ID_REFRESH = wx.NewId()
-        self.refreshBtn = wx.Button(self, ID_REFRESH, _(u'Refresh'), )
-        self.cancelBtn = wx.Button(self, wx.ID_CANCEL, _(u'Close'), )
+        self.refreshBtn = wx.Button(self, ID_REFRESH, _('Refresh'), )
+        self.cancelBtn = wx.Button(self, wx.ID_CANCEL, _('Close'), )
 
         self.Bind(wx.EVT_BUTTON, self.OnRefreshServerInfo, self.refreshBtn)
         self.Bind(wx.EVT_BUTTON, self.OnCancel, self.cancelBtn)
@@ -128,34 +128,34 @@ class PyHocaGUI_DialogBoxServerInfo(wx.Dialog):
     def _refreshServerInfo(self):
 
         server_components = self._PyHocaGUI.get_server_components(self.current_profile_name, force=True)
-        server_extensions = [ k for k in server_components.keys() if k.startswith('x2goserver-') and k != 'x2goserver-common' ]
+        server_extensions = [ k for k in list(server_components.keys()) if k.startswith('x2goserver-') and k != 'x2goserver-common' ]
         server_extensions.sort()
-        server_addons = [ k for k in server_components.keys() if not k.startswith('x2goserver') and k != 'x2goagent' ]
+        server_addons = [ k for k in list(server_components.keys()) if not k.startswith('x2goserver') and k != 'x2goagent' ]
         server_addons.sort()
         server_features = self._PyHocaGUI.get_server_features(self.current_profile_name, force=True)
         halftab = '    '
         newline = '\n'
 
-        self.infoArea.AppendText(_(u'X2Go Server')+':'+2*newline)
-        self.infoArea.AppendText(halftab+_(u'Server Core')+':'+newline)
+        self.infoArea.AppendText(_('X2Go Server')+':'+2*newline)
+        self.infoArea.AppendText(halftab+_('Server Core')+':'+newline)
         self.infoArea.AppendText(newline)
         self.infoArea.AppendText(2*halftab+'%s (%s)\n' % ('x2goserver', server_components['x2goserver']))
-        if 'x2goserver-common' in server_components.keys():
+        if 'x2goserver-common' in list(server_components.keys()):
             self.infoArea.AppendText(2*halftab+'%s (%s)\n' % ('x2goserver-common', server_components['x2goserver-common']))
         self.infoArea.AppendText(2*halftab+'%s (%s)\n' % ('x2goagent', server_components['x2goagent']))
         self.infoArea.AppendText('\n')
         if server_extensions:
-            self.infoArea.AppendText(halftab+_(u'Server Extensions')+':'+newline)
+            self.infoArea.AppendText(halftab+_('Server Extensions')+':'+newline)
             self.infoArea.AppendText(newline)
             for comp in server_extensions:
                 self.infoArea.AppendText(2*halftab+'%s (%s)\n' % (comp, server_components[comp]))
         self.infoArea.AppendText('\n')
         if server_addons:
-            self.infoArea.AppendText(_(u'X2Go Server Add-ons')+':'+2*newline)
+            self.infoArea.AppendText(_('X2Go Server Add-ons')+':'+2*newline)
             for comp in server_addons:
                 self.infoArea.AppendText(2*halftab+'%s (%s)\n' % (comp, server_components[comp]))
         self.infoArea.AppendText('\n')
-        self.infoArea.AppendText(_(u'X2Go Server Features')+':'+2*newline)
+        self.infoArea.AppendText(_('X2Go Server Features')+':'+2*newline)
         for feature in server_features:
             self.infoArea.AppendText(2*halftab+'%s\n' % (feature))
         self.infoArea.ShowPosition(0)
