@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -22,10 +22,20 @@
 import wx
 import os
 
-# PyHoca-GUI modules
-import basepath
+wx_major = int(wx.__version__.split('.')[0])
+if wx_major < 4:
+    from wx import SplashScreen as _SplashScreen
+    _wx_SPLASH_CENTRE_ON_SCREEN = wx.SPLASH_CENTRE_ON_SCREEN
+    _wx_SPLASH_TIMEOUT = wx.SPLASH_TIMEOUT
+else:
+    from wx.adv import SplashScreen as _SplashScreen
+    _wx_SPLASH_CENTRE_ON_SCREEN = wx.adv.SPLASH_CENTRE_ON_SCREEN
+    _wx_SPLASH_TIMEOUT = wx.adv.SPLASH_TIMEOUT
 
-class PyHocaGUI_SplashScreen(wx.SplashScreen):
+# PyHoca-GUI modules
+from . import basepath
+
+class PyHocaGUI_SplashScreen(_SplashScreen):
     """\
     L{PyHocaGUI} splash screen that gets shown an application startup.
 
@@ -57,13 +67,13 @@ class PyHocaGUI_SplashScreen(wx.SplashScreen):
             splash_wximage.Rescale(400, int(float(400)/splash_wximage.Width*splash_wximage.Height))
 
             splash_wxbitmap = splash_wximage.ConvertToBitmap()
-            wx.SplashScreen.__init__(self,
-                                     splash_wxbitmap,
-                                     splashStyle=wx.SPLASH_CENTRE_ON_SCREEN|wx.SPLASH_TIMEOUT,
-                                     milliseconds=5000,
-                                     parent=None,
-                                     style=wx.SIMPLE_BORDER|wx.STAY_ON_TOP|wx.FRAME_NO_TASKBAR
-                                    )
+            _SplashScreen.__init__(self,
+                                   splash_wxbitmap,
+                                   splashStyle=_wx_SPLASH_CENTRE_ON_SCREEN|_wx_SPLASH_TIMEOUT,
+                                   milliseconds=5000,
+                                   parent=None,
+                                   style=wx.SIMPLE_BORDER|wx.STAY_ON_TOP|wx.FRAME_NO_TASKBAR
+                                  )
             self.Bind(wx.EVT_CLOSE, self.OnClose)
 
     def OnClose(self, evt):
