@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim:fenc=utf-8
 
-# Copyright (C) 2010-2019 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # Copyright (C) 2010-2016 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
@@ -25,6 +25,12 @@ modules ={}
 import x2go
 
 import wx
+wx_major = int(wx.__version__.split('.')[0])
+if wx_major < 4:
+    from wx import TaskBarIcon as _TaskBarIcon
+else:
+    from wx.adv import TaskBarIcon as _TaskBarIcon
+
 import os
 
 # Warning: If pyflakes says you should delete these 2 lines,
@@ -35,8 +41,8 @@ if x2go.X2GOCLIENT_OS == 'Windows':
     import win32gui
 
 # PyHoca-GUI modules
-import menus_taskbar
-import basepath
+from . import menus_taskbar
+from . import basepath
 
 
 def MakeIcon(icon_name, fallback_name='PyHoca-GUI_trayicon.png', appname="PyHoca-GUI"):
@@ -77,11 +83,14 @@ def MakeIcon(icon_name, fallback_name='PyHoca-GUI_trayicon.png', appname="PyHoca
         icon_file = '%s/%s/%s/%s' % (_icons_location, icon_folder, icon_size, fallback_name)
 
     img = wx.Image(icon_file)
-    icon = wx.IconFromBitmap(img.ConvertToBitmap())
+    if wx_major < 4:
+        icon = wx.IconFromBitmap(img.ConvertToBitmap())
+    else:
+        icon = wx.Icon(img.ConvertToBitmap())
     return icon
 
 
-class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
+class PyHocaGUI_TaskBarIcon(_TaskBarIcon):
     """\
     Class for the L{PyHocaGUI} taskbar icon.
 
@@ -96,7 +105,7 @@ class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
         @type about: C{obj}
 
         """
-        wx.TaskBarIcon.__init__(self)
+        _TaskBarIcon.__init__(self)
         self._PyHocaGUI = about._PyHocaGUI
         self._pyhoca_logger = self._PyHocaGUI._pyhoca_logger
         self._pyhoca_logger('start TaskBarIcon of type: %s' % (wx.PlatformInfo, ), loglevel=x2go.loglevel_INFO)
@@ -116,11 +125,11 @@ class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
         if x2go.X2GOCLIENT_OS == 'Windows':
             icon_name = self._PyHocaGUI.tray_icon_connecting or self._PyHocaGUI.tray_icon
             self.icon = MakeIcon(icon_name=icon_name, appname=self._PyHocaGUI.appname)
-            self.SetIcon(self.icon, _(u"%s\nConnecting you to ,,%s\'\'") % (self._PyHocaGUI.appname, profile_name))
+            self.SetIcon(self.icon, _("%s\nConnecting you to ,,%s\'\'") % (self._PyHocaGUI.appname, profile_name))
         else:
             icon_name = self._PyHocaGUI.tray_icon_connecting or self._PyHocaGUI.tray_icon
             self.icon = MakeIcon(icon_name=icon_name, appname=self._PyHocaGUI.appname)
-            self.SetIcon(self.icon, _(u"%s\nCurrently connecting you to remote X2Go server ,,%s\'\'") % (self._PyHocaGUI.appname, profile_name))
+            self.SetIcon(self.icon, _("%s\nCurrently connecting you to remote X2Go server ,,%s\'\'") % (self._PyHocaGUI.appname, profile_name))
 
     def SetIconIdle(self):
         """\
@@ -130,11 +139,11 @@ class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
         if x2go.X2GOCLIENT_OS == 'Windows':
             icon_name = self._PyHocaGUI.tray_icon
             self.icon = MakeIcon(icon_name=icon_name, appname=self._PyHocaGUI.appname)
-            self.SetIcon(self.icon, _(u"%s\nConnecting you to X2Go...") % self._PyHocaGUI.appname)
+            self.SetIcon(self.icon, _("%s\nConnecting you to X2Go...") % self._PyHocaGUI.appname)
         else:
             icon_name = self._PyHocaGUI.tray_icon
             self.icon = MakeIcon(icon_name=icon_name, appname=self._PyHocaGUI.appname)
-            self.SetIcon(self.icon, _(u"%s\nClient for connecting you to a remote X2Go server") % self._PyHocaGUI.appname)
+            self.SetIcon(self.icon, _("%s\nClient for connecting you to a remote X2Go server") % self._PyHocaGUI.appname)
 
     def CreateSessionManagerPopupMenu(self, evt):
         """\
@@ -175,7 +184,10 @@ class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
         @rtype: C{obj}
 
         """
-        self.menu_optionsmanager = self.PopupMenu(menus_taskbar.PyHocaGUI_Menu_TaskbarOptionsManager(self._PyHocaGUI, caller=self,))
+        if wx_major < 4:
+            self.menu_optionsmanager = self.PopupMenu(menus_taskbar.PyHocaGUI_Menu_TaskbarOptionsManager(self._PyHocaGUI, caller=self,))
+        else:
+            self.menu_optionsmanager = menus_taskbar.PyHocaGUI_Menu_TaskbarOptionsManager(self._PyHocaGUI, caller=self,)
         return self.menu_optionsmanager
 
     def Close(self):
